from .commonuicomponents import CommonUIComponents
from .widgets import SmartWidget
